@@ -3,6 +3,8 @@
 use strict;
 use warnings;
 
+use Encode;
+use Encode::Locale;
 use Getopt::Long;
 use Pod::Usage;
 use SOAP::Lite;
@@ -10,6 +12,10 @@ use App::OTRS::CreateTicket;
 
 print "$0 version " .  App::OTRS::CreateTicket->VERSION() . "\n\n";
 
+@ARGV = map { decode(locale => $_, 1) } @ARGV if -t STDIN;
+binmode STDOUT, ":encoding(console_out)" if -t STDOUT;
+binmode STDERR, ":encoding(console_out)" if -t STDERR;
+
 my @TicketFields
     = qw ( Title CustomerUser Queue Priority State Type Service SLA Owner Responsible );
 my @ArticleFields = qw ( Subject Body ContentType ArticleType SenderType );
